pub fn generate_three_js_html(props: &ThreeViewProps) -> StringExpand description
Generate the HTML with embedded Three.js Includes full raycasting, selection, and gizmo interaction support
pub fn generate_three_js_html(props: &ThreeViewProps) -> StringGenerate the HTML with embedded Three.js Includes full raycasting, selection, and gizmo interaction support